package chartjs

  1. Overview
  2. Docs

Module Chartjs.Tooltip_positionSource

Sourcetype t
Sourceval average : t

Will place the tooltip at the average position of the items displayed in the tooltip.

Sourceval nearest : t

Will place the tooltip at the position of the element closest to the event position.

Sourceval of_string : string -> t